# phondler
A **phon**etic han**dler** for Python. Makes phonetic representations (IPA, X-SAMPA, others) interoperable and creates a phoneme data dictionary to enable other packages to work on phonemes.

* phondler:
  * phondler_tables.py - tables mapping phonetic representations
  * phondler.py - tools for converting strings between representations
  * pronlex.py - tools for reading, writing, converting, and searching pronunciation lexicon files in several standard formats.

* test: test scripts and example files, showing how to use these tools.

